@@ -128,7 +128,7 @@ class EdgeFunction(
         :param description: A description of the function. Default: - No description.
         :param environment: Key-value pairs that Lambda caches and makes available for your Lambda functions. Use environment variables to apply configuration changes, such as test and production environment configurations, without changing your Lambda function source code. Default: - No environment variables.
         :param environment_encryption: The AWS KMS key that's used to encrypt your function's environment variables. Default: - AWS Lambda creates and uses an AWS managed customer master key (CMK).
-        :param ephemeral_storage_size: The size of the function’s /tmp directory in MB. Default: 512 MiB
+        :param ephemeral_storage_size: The size of the function’s /tmp directory in MiB. Default: 512 MiB
         :param events: Event sources for this function. You can also add event sources using ``addEventSource``. Default: - No event sources.
         :param filesystem: The filesystem configuration for the lambda function. Default: - will not mount any filesystem
         :param function_name: A name for the function. Default: - AWS CloudFormation generates a unique physical ID and uses that ID for the function's name. For more information, see Name Type.
@@ -304,6 +304,22 @@ class EdgeFunction(
 
         return typing.cast(aws_cdk.aws_lambda.EventSourceMapping, jsii.invoke(self, "addEventSourceMapping", [id, options]))
 
+    @jsii.member(jsii_name="addFunctionUrl")
+    def add_function_url(
+        self,
+        *,
+        auth_type: typing.Optional[aws_cdk.aws_lambda.FunctionUrlAuthType] = None,
+        cors: typing.Optional[aws_cdk.aws_lambda.FunctionUrlCorsOptions] = None,
+    ) -> aws_cdk.aws_lambda.FunctionUrl:
+        '''Adds a url to this lambda function.
+
+        :param auth_type: The type of authentication that your function URL uses. Default: FunctionUrlAuthType.AWS_IAM
+        :param cors: The cross-origin resource sharing (CORS) settings for your function URL. Default: - No CORS configuration.
+        '''
+        options = aws_cdk.aws_lambda.FunctionUrlOptions(auth_type=auth_type, cors=cors)
+
+        return typing.cast(aws_cdk.aws_lambda.FunctionUrl, jsii.invoke(self, "addFunctionUrl", [options]))
+
     @jsii.member(jsii_name="addPermission")
     def add_permission(
         self,
@@ -312,6 +328,7 @@ class EdgeFunction(
         principal: aws_cdk.aws_iam.IPrincipal,
         action: typing.Optional[builtins.str] = None,
         event_source_token: typing.Optional[builtins.str] = None,
+        function_url_auth_type: typing.Optional[aws_cdk.aws_lambda.FunctionUrlAuthType] = None,
         scope: typing.Optional[aws_cdk.core.Construct] = None,
         source_account: typing.Optional[builtins.str] = None,
         source_arn: typing.Optional[builtins.str] = None,
@@ -322,6 +339,7 @@ class EdgeFunction(
         :param principal: The entity for which you are granting permission to invoke the Lambda function. This entity can be any valid AWS service principal, such as s3.amazonaws.com or sns.amazonaws.com, or, if you are granting cross-account permission, an AWS account ID. For example, you might want to allow a custom application in another AWS account to push events to Lambda by invoking your function. The principal can be either an AccountPrincipal or a ServicePrincipal.
         :param action: The Lambda actions that you want to allow in this statement. For example, you can specify lambda:CreateFunction to specify a certain action, or use a wildcard (``lambda:*``) to grant permission to all Lambda actions. For a list of actions, see Actions and Condition Context Keys for AWS Lambda in the IAM User Guide. Default: 'lambda:InvokeFunction'
         :param event_source_token: A unique token that must be supplied by the principal invoking the function. Default: The caller would not need to present a token.
+        :param function_url_auth_type: The authType for the function URL that you are granting permissions for. Default: - No functionUrlAuthType
         :param scope: The scope to which the permission constructs be attached. The default is the Lambda function construct itself, but this would need to be different in cases such as cross-stack references where the Permissions would need to sit closer to the consumer of this permission (i.e., the caller). Default: - The instance of lambda.IFunction
         :param source_account: The AWS account ID (without hyphens) of the source owner. For example, if you specify an S3 bucket in the SourceArn property, this value is the bucket owner's account ID. You can use this property to ensure that all source principals are owned by a specific account.
         :param source_arn: The ARN of a resource that is invoking your function. When granting Amazon Simple Storage Service (Amazon S3) permission to invoke your function, specify this property with the bucket ARN as its value. This ensures that events generated only from the specified bucket, not just any bucket from any AWS account that creates a mapping to your function, can invoke the function.
@@ -330,6 +348,7 @@ class EdgeFunction(
             principal=principal,
             action=action,
             event_source_token=event_source_token,
+            function_url_auth_type=function_url_auth_type,
             scope=scope,
             source_account=source_account,
             source_arn=source_arn,
@@ -381,6 +400,17 @@ class EdgeFunction(
         '''
         return typing.cast(aws_cdk.aws_iam.Grant, jsii.invoke(self, "grantInvoke", [identity]))
 
+    @jsii.member(jsii_name="grantInvokeUrl")
+    def grant_invoke_url(
+        self,
+        identity: aws_cdk.aws_iam.IGrantable,
+    ) -> aws_cdk.aws_iam.Grant:
+        '''Grant the given identity permissions to invoke this Lambda Function URL.
+
+        :param identity: -
+        '''
+        return typing.cast(aws_cdk.aws_iam.Grant, jsii.invoke(self, "grantInvokeUrl", [identity]))
+
     @jsii.member(jsii_name="metric")
     def metric(
         self,
@@ -805,7 +835,7 @@ class EdgeFunctionProps(aws_cdk.aws_lambda.FunctionProps):
         :param description: A description of the function. Default: - No description.
         :param environment: Key-value pairs that Lambda caches and makes available for your Lambda functions. Use environment variables to apply configuration changes, such as test and production environment configurations, without changing your Lambda function source code. Default: - No environment variables.
         :param environment_encryption: The AWS KMS key that's used to encrypt your function's environment variables. Default: - AWS Lambda creates and uses an AWS managed customer master key (CMK).
-        :param ephemeral_storage_size: The size of the function’s /tmp directory in MB. Default: 512 MiB
+        :param ephemeral_storage_size: The size of the function’s /tmp directory in MiB. Default: 512 MiB
         :param events: Event sources for this function. You can also add event sources using ``addEventSource``. Default: - No event sources.
         :param filesystem: The filesystem configuration for the lambda function. Default: - will not mount any filesystem
         :param function_name: A name for the function. Default: - AWS CloudFormation generates a unique physical ID and uses that ID for the function's name. For more information, see Name Type.
@@ -1125,7 +1155,7 @@ class EdgeFunctionProps(aws_cdk.aws_lambda.FunctionProps):
 
     @builtins.property
     def ephemeral_storage_size(self) -> typing.Optional[aws_cdk.core.Size]:
-        '''The size of the function’s /tmp directory in MB.
+        '''The size of the function’s /tmp directory in MiB.
 
         :default: 512 MiB
         '''
